#
# spec file for package godot
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017 Luke Jones, luke.nukem.jones@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# faster_build only builds the editor to speed up the build.
%define faster_build 0

%define _buildshell /bin/bash
%define ca_bundle %{_localstatedir}/lib/ca-certificates/ca-bundle.pem

Name:           godot
Version:        3.2.3
Release:        2.2
Summary:        Cross-Platform Game Engine with an Integrated Editor
License:        MIT
Group:          Development/Tools/Other
URL:            https://godotengine.org/
Source0:        https://downloads.tuxfamily.org/godotengine/%{version}/%{name}-%{version}-stable.tar.xz
Source1:        https://downloads.tuxfamily.org/godotengine/%{version}/%{name}-%{version}-stable.tar.xz.sha256
# Project policy does not allow "-no-pie"
Patch0:         linker_pie_flag.patch
# Use system certificates as fallback for certificates
Patch1:         certs_fallback.patch
# PATCH-FIX-UPSTREAM upstream_fix_TGA_loader.patch boo#1182177 boo#1182178
# commit 113b5ab1c45c01b8e6d54d13ac8876d091f883a8
Patch2:         upstream_fix_TGA_loader.patch
BuildRequires:  Mesa-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scons
BuildRequires:  update-desktop-files
BuildRequires:  yasm-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libpcre2-32)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(theoradec)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1500
BuildRequires:  mbedtls-devel
BuildRequires:  pkgconfig(bullet)
BuildRequires:  pkgconfig(libwslay)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(miniupnpc)
%else
%if 0%{?is_opensuse}
# SLES seems not to have wslay and miniupnpc
BuildRequires:  libminiupnpc-devel
BuildRequires:  pkgconfig(libwslay)
%if 0%{?sle_version} >= 150200
BuildRequires:  mbedtls-devel
%endif
%endif
%endif
Requires:       ca-certificates
Recommends:     ca-certificates-mozilla
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
Recommends:     %{name}-bash-completion
Suggests:       %{name}-headless = %{version}
Suggests:       %{name}-runner = %{version}
Suggests:       %{name}-server = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# The following "Provides: bundled()" and comments were taken from the 
# Fedora Godot specfile. 
# Link: https://src.fedoraproject.org/rpms/godot/blob/master/f/godot.spec

# Has some modifications for IPv6 support, upstream enet is unresponsive
# Should not be unbundled.
Provides:       bundled(enet) = 1.3.15

# Has custom changes to support seeking in zip archives
# Should not be unbundled.
Provides:       bundled(minizip) = 1.2.11

Provides:       bundled(FastLZ)
Provides:       bundled(Tangent_Space_Normal_Maps)
Provides:       bundled(cvtt)
Provides:       bundled(easing)
Provides:       bundled(etc2comp)
Provides:       bundled(glad)
Provides:       bundled(google-droid-fonts)
Provides:       bundled(hack-fonts)
Provides:       bundled(hqx)
Provides:       bundled(ifaddrs-android)
Provides:       bundled(jpeg-compressor)
Provides:       bundled(libsimplewebm)
Provides:       bundled(noto-sans-fonts)
Provides:       bundled(open-simplex-noise-in-c)
Provides:       bundled(pcg)
Provides:       bundled(polyclipping)
Provides:       bundled(polypartition)
Provides:       bundled(pvrtccompressor)
Provides:       bundled(smaz)
Provides:       bundled(stb)
Provides:       bundled(tinyexr)
Provides:       bundled(vhacd)
Provides:       bundled(yuv2rgb)

# Can be unbundled if packaged
Provides:       bundled(nanosvg)
Provides:       bundled(recastnavigation)
Provides:       bundled(squish) = 1.15
Provides:       bundled(xatlas)

## Need to update in Factory ##
# Possibility to unbundle disabled in 3.2.1
Provides:       bundled(assimp)

%if 0%{?suse_version} > 1500
%else
Provides:       bundled(bullet) = 2.89
Provides:       bundled(libzstd)
%if 0%{?sle_version} < 150200
Provides:       bundled(mbedtls) = 2.16.8
%endif
%if !0%{?is_opensuse}
# SLES seems not to have miniupnpc and wslay
Provides:       bundled(libwslay) = 1.1.1
Provides:       bundled(miniupnpc)
%endif
%endif

%description
Godot is a game engine. It provides a set of tools and a visually
oriented workflow that can export games to PC, Mobile and Web
platforms.

%if !0%{?faster_build}

%package headless
Summary:        Headless version of Godot editor useful for command line
Group:          Development/Tools/Other
Requires:       ca-certificates
Recommends:     ca-certificates-mozilla
Suggests:       %{name}-bash-completion

%description headless
This package is the headless version of the Godot editor that is suited for 
exporting Godot games on the command line.

%package runner
Summary:        Shared binary to play games developed with the Godot engine
Group:          Amusements/Games/Other
Requires:       ca-certificates
Recommends:     ca-certificates-mozilla
Suggests:       %{name}-bash-completion

%description runner
This package contains a godot-runner binary for the Linux X11 platform,
which can be used to run any game developed with the Godot engine simply
by pointing to the location of the game's data package.

%package server
Summary:        Godot headless binary for servers
Group:          Amusements/Games/Other
Requires:       ca-certificates
Recommends:     ca-certificates-mozilla
Suggests:       %{name}-bash-completion

%description server
This package contains the headless binary for the Godot game engine
particularly suited for running dedicated servers.

%endif

%package bash-completion
Summary:        Godot command line completion for Bash
Group:          Amusements/Games/Other
BuildArch:      noarch
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
Enhances:       (%{name}-headless and bash-completion)
Enhances:       (%{name}-runner and bash-completion)
Enhances:       (%{name}-server and bash-completion)

%description bash-completion
Bash command line completion support for %{name}, %{name}-headless,
%{name}-runner and %{name}-server

%prep
%setup -q -n %{name}-%{version}-stable
%patch0 -p1
%patch1 -p1
%patch2 -p1

cp thirdparty/README.md thirdparty_README.md

# actual doc location in openSUSE
sed -i 's/\/usr\/share\/doc\/godot\//\/usr\/share\/doc\/packages\/godot\//' misc/dist/linux/godot.6

if [[ -z "$(desktop-file-validate misc/dist/linux/org.godotengine.Godot.desktop)" ]];
 then
  # desktop-file-utils version >= 0.25
  echo desktop-file-utils is up to date and recognizes PrefersNonDefaultGPU.
  # rpmlint complains nevertheless (on Tumbleweed). A false negative?
  # see https://specifications.freedesktop.org/desktop-entry-spec/desktop-entry-spec-latest.html#recognized-keys
  # Perhaps because rpmlint-mini includes as of today (18.09.2020)
  # desktop-file-utils-0.24 while we checked for available default version >= 0.25
 else
  echo PrefersNonDefaultGPU not recognized.
  # rpmlint considers file invalid without "X-" prefix
  sed -i 's/PrefersNonDefaultGPU=true/X-PrefersNonDefaultGPU=true/' misc/dist/linux/org.godotengine.Godot.desktop
fi

# disarm shebang
sed -i '1s/#!/##/' misc/dist/shell/godot.bash-completion

# bash completion for sub packages
cp misc/dist/shell/godot.bash-completion misc/dist/shell/godot-headless
cp misc/dist/shell/godot.bash-completion misc/dist/shell/godot-runner
cp misc/dist/shell/godot.bash-completion misc/dist/shell/godot-server

sed -i '$s/_complete_godot_bash godot/_complete_godot_bash godot-headless/' misc/dist/shell/godot-headless
sed -i '$s/_complete_godot_bash godot/_complete_godot_bash godot-runner/' misc/dist/shell/godot-runner
sed -i '$s/_complete_godot_bash godot/_complete_godot_bash godot-server/' misc/dist/shell/godot-server

%build
# Configuring build to use some distribution libraries
unbundle_libs=('certs' 'freetype' 'libogg' 'libpng' 'libtheora' 'libvorbis' \
               'libwebp' 'opus' 'pcre2' 'zlib')

# Adding distribution name to build name
%if 0%{?suse_version}
  %if 0%{?is_opensuse}
    # Unbundle more libs for openSUSE
    unbundle_libs+=('miniupnpc' 'wslay')
    export BUILD_NAME="openSUSE"
  %else
    export BUILD_NAME="SUSE"
  %endif
%endif

# Unbundle more libs for Tumbleweed
%if %{suse_version} > 1500
unbundle_libs+=('bullet' 'mbedtls' 'zstd')
%else
# Unbundle more libs for coming Leap
%if 0%{?sle_version} >= 150200 && 0%{?is_opensuse}
unbundle_libs+=('mbedtls')
%endif
%endif

# Unbundle libvpx only if it doesn't meet the minimum requirement.
# See: https://github.com/godotengine/godot/tree/master/thirdparty#libvpx
vpx_version_min=1.6.0
vpx_version=$(pkg-config --modversion vpx)
if [[ $vpx_version = $vpx_version_min || $vpx_version > $vpx_version_min ]]; then
  unbundle_libs+=('libvpx')
fi

system_libs=""
for thirdparty in "${unbundle_libs[@]}"; do
  system_libs="$system_libs builtin_$thirdparty=no"
  rm -rf thirdparty/$thirdparty
done

# Keep empty certificates file needed as "source" by
# function "make_certs_header" in core/core_builders.py
mkdir -pv thirdparty/certs
touch thirdparty/certs/ca-certificates.crt

%define build_args %{?_smp_mflags} \\\
        progress=yes verbose=yes udev=yes use_lto=1 \\\
        CCFLAGS='%{optflags}' \\\
        system_certs_path=%{ca_bundle} $system_libs

# Build graphical editor (tools)
# rename x11 to linuxbsd ?
scons %{build_args} platform=x11 tools=yes target=release_debug

%if !0%{?faster_build}
# Build headless version of the editor (with tools)
scons %{build_args} platform=server tools=yes target=release_debug

# Build game runner (without tools)
scons %{build_args} platform=x11 tools=no target=release

# Build server version (without tools)
scons %{build_args} platform=server tools=no target=release
%endif

%install
# Installing the editor
install -D -p -m 755 bin/%{name}.x11.opt.tools.%{__isa_bits} %{buildroot}%{_bindir}/%{name}

install -D -p -m 644 misc/dist/linux/godot.6 %{buildroot}/%{_mandir}/man6/%{name}.6%{?ext_man}
install -D -p -m 644 icon.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -D -p -m 644 icon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -D -p -m 644 misc/dist/linux/org.godotengine.Godot.appdata.xml  %{buildroot}%{_datadir}/metainfo/org.godotengine.Godot.appdata.xml
%suse_update_desktop_file -i org.godotengine.Godot

%if !0%{?faster_build}
# Installing the headless editor
install -D -p -m 755 bin/%{name}_server.x11.opt.tools.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-headless

# Installing the runner
install -D -p -m 755 bin/%{name}.x11.opt.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-runner

# Installing the server
install -D -p -m 755 bin/%{name}_server.x11.opt.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-server
%endif

# Installing bash-completion
install -D -p -m 644 misc/dist/shell/godot.bash-completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -D -p -m 644 misc/dist/shell/godot-headless %{buildroot}%{_datadir}/bash-completion/completions/%{name}-headless
install -D -p -m 644 misc/dist/shell/godot-runner %{buildroot}%{_datadir}/bash-completion/completions/%{name}-runner
install -D -p -m 644 misc/dist/shell/godot-server %{buildroot}%{_datadir}/bash-completion/completions/%{name}-server

%fdupes -s %{buildroot}/%{_prefix}

%files
%license LICENSE.txt LOGO_LICENSE.md COPYRIGHT.txt thirdparty_README.md
%doc AUTHORS.md CHANGELOG.md CONTRIBUTING.md DONORS.md README.md logo.svg
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_bindir}/%{name}
%{_datadir}/metainfo/org.godotengine.Godot.appdata.xml
%{_datadir}/applications/org.godotengine.Godot.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man6/%{name}.6%{?ext_man}

%if !0%{?faster_build}
%files headless
%license LICENSE.txt LOGO_LICENSE.md COPYRIGHT.txt thirdparty_README.md
%doc AUTHORS.md CHANGELOG.md CONTRIBUTING.md DONORS.md README.md logo.svg
%{_bindir}/%{name}-headless

%files runner
%license LICENSE.txt LOGO_LICENSE.md COPYRIGHT.txt thirdparty_README.md
%doc AUTHORS.md CHANGELOG.md CONTRIBUTING.md DONORS.md README.md logo.svg
%{_bindir}/%{name}-runner

%files server
%license LICENSE.txt LOGO_LICENSE.md COPYRIGHT.txt thirdparty_README.md
%doc AUTHORS.md CHANGELOG.md CONTRIBUTING.md DONORS.md README.md logo.svg
%{_bindir}/%{name}-server
%endif

%files bash-completion
%license LICENSE.txt COPYRIGHT.txt
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/bash-completion/completions/%{name}-headless
%{_datadir}/bash-completion/completions/%{name}-runner
%{_datadir}/bash-completion/completions/%{name}-server

%changelog
* Sat Feb 13 2021 cunix@mail.de
- Fix a crash in the TGA loader with malformed input
  * added upstream_fix_TGA_loader.patch from upstream
  * integer overflow issue CVE-2021-26825 (boo#1182177)
  * stack overflow issue CVE-2021-26826 (boo#1182178)
* Sun Nov  1 2020 Yunhe Guo <i@guoyunhe.me>
- Fix AppStream file location to match latest standard
* Fri Sep 18 2020 cunix@mail.de
- Update to 3.2.3
  Added:
  * Input: Support SDL2 half axes and inverted axes mappings
  * LineEdit: Add option to disable virtual keyboard for LineEdit
  * Rendering: Allow nearest neighbor lookup when using mipmaps
  Changed:
  * GDScript: Auto completion enhanced for extends and
    class level identifier
  * Physics: Better damping implementation for Bullet rigid bodies.
    If you're using damping with the Bullet backend,
    you may need to adjust some properties to restore
    the behavior from 3.2.2 or earlier.
  * Project Settings: Enable file logging by default on desktops
  * Script editor: Don't open dominant script in external editor
  * Sprite3D: Use mesh instead of immediate for drawing Sprite3D
  Fixed:
  * Core: debugger error when Dictionary key is a freed Object
  * Core: leaked ObjectRCs on object Variant reassignment
  * GLES3: OpenGL error when generating radiance
  * Import: custom tracks causing issues on reimport
  * Import: regression causing crashes with some OGG files
  * Particles: 2D Particle velocity with directed emission mask
  * PathFollow3D: repeated updates of PathFollow3D Transform
  * Physics: Trigger broadphase update when changing collision layer/mask
  * Physics: laxist collision detection on one way shapes
  * Physics: Properly pass safe margin on initialization
  * Project Settings: overriding compression related settings
  * Rendering: images in black margins
  * Rendering: Properly calculate Polygon2D AABB with skeleton
  * Shaders: specular 'render_mode' for Visual Shaders
  And more:
  https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_changelog_chrono.txt
- "certs_fallback.patch" rebased
* Wed Jul  1 2020 cunix@mail.de
- In .desktop file prefix "PrefersNonDefaultGPU" with "X-" only
  until package desktop-file-utils is up to date.
* Fri Jun 26 2020 cunix@mail.de
- In .desktop file "PrefersNonDefaultGPU" prefixed with "X-"
* Fri Jun 26 2020 Max Mitschke <maxmitschke@fastmail.com>
- Update to 3.2.2
  Highlights:
  * 2D batching for the GLES2 renderer
  * C# support for the iOS platform
  * Re-architecture of the Android plugin system
  * DTLS support and ENet integration
  * Better handling of Variants pointing to released Objects
  * Updated and localized documentation
  Added:
  * 2D: MODULATE builtin for canvas item shaders
  * Editor: rotation widget in 3D viewport
  * Editor: Allow duplicating files when holding Control
  * GLES2/GLES3: support for OpenGL external textures
  * Import: support for glTF lights
  * Input: keyboard layout enumeration / set / get functions
  * Object: has_signal method
  * RegEx: Enable Unicode support for RegEx class
  * Shaders: shader time scaling
  * Add 'custom_modules' build option to compile external user modules
  * SCons: Allow to read 'custom_modules' option via a file
  * Provide the ability for clients of the Godot library
    to add their own command line arguments
  * Request the dedicated GPU when starting Godot from the '.desktop' file
  * set_frame, pause, and oneshot to AnimatedTexture
  * selection outline to locked nodes
  Fixed:
  * Audio: volume interpolation in positional audio nodes
  * Import: changing the import type of multiple files at once
  * Particles: uninitialized memory in CPUParticles and CPUParticles2D
  * Physics: Make soft body completely stiff to attachment point
  * Physics: Normalize up direction vector in move_and_slide()
  * Account for file deletion and renaming in Export Presets
  * can't convert Transform -> Transform2D
  * Emit signal when animation ends by seek
  * Othographic camera in-editor now uses Z near/far settings
    instead of a hardcoded value
  * Editor 2D: Change pixel alignment strategy, jittering in high zoom
  * Allow single quotes in comments
  And more:
  https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_changelog_chrono.txt
- "linker_pie_flag.patch" adjusted.
* Tue Mar 10 2020 cunix@mail.de
- Update to 3.2.1
  Fixed:
  * Bullet: Fix detection of concave shape in Area.
  * Camera2D: Fix inverted use of Camera2D offset_v.
  * Debugger: Fix crash inspecting freed objects.
  * Expression: Fix parsing integers as 32-bit.
  * Particles: Fix undefined behavior with atan in GPU Particles.
  * TileSet: Hide TileSet properties from Inspector, fixing
    OOM crash on huge tilesets.
  * Video: Workaround WebM playback bug after AudioServer latency fixes.
  Added:
  * Skin: Add support for named binds.
  * API documentation updates.
  * Editor translation updates.
  And more:
  https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_changelog_chrono.txt
- "linker_pie_flag.patch" adjusted.
* Wed Feb 12 2020 cunix@mail.de
- Added "linker_pie_flag.patch" in order to link with "-pie".
    Replaces previous "fix-pie-warning.patch".
- "project_certs_fallback.patch" renamed to "certs_fallback.patch".
    Modified and adapted to Godot source code changes.
- Bash completion files "godot", "godot-headless", "godot-runner"
    and "godot-server" added.
- Package "godot-bash-completion" added.
- Location of documentation in man page adjusted.
- godot-rpmlintrc deleted with filter "no-manual-page-for-binary"
    because this warning doesn't seems to be thrown anymore.
- Build option "faster_build" introduced to speed up build
    during tests.
* Sat Feb  1 2020 Max Mitschke <maxmitschke@fastmail.com>
- Removed patch "fix-pie-warning.patch"
- Removed export_presets.cfg file as games should supply this file
- Update to v3.2
  Added:
  * Support for importing 3D scense using Assimp
  * Support for high-level multiplayer API and NAT traversal for
    WebRTC
  * Support for enabling / disabling parts of the editor or specific
    nodes
  * Added language server for GDScript
  * Added version control integration into the editor
  * Added a network profiler
  * Editor is now capped to 20FPS when the window is unfocused
  * Added MSAA support in the GLES2 renderer
  * Ability to define script templates on a per-project basis
  * Ability to limit the minimum and maximum window size
  * Minimap in the script editor
  * CSV files can now be imported as non-translation files
  * Multicast support in PacketPeerUDP
  * WebSocket improvements.
  * Support for SSL in WebSocketServer.
  * WebSocketClient can now use custom SSL certificates
    (except on HTML5).
  * WebSocketClient can now define custom headers.
  * The editor now features a built-in Web server for testing HTML5
    projects
  * Reimplemented support for embedding project data in the PCK file
  Changed:
  * Tabs and space indentation can no longer be mixed in the same
    GDScript file
  * assert() in GDScript must now always be used with parentheses
  * UDP broadcasting is now disabled by default and must be enabled
    by calling
    set_broadcast_enabled(true) on the PacketPeerUDP instance
  * 3D collision shapes and RayCasts are now drawn in gray when disabled
  * The SCons build system now automatically detects the host platform
  * Exporting a project PCK or ZIP from the command line must now
    be done with the new --export-pack command-line argument
  * Exported PCK files now contain the Godot patch version in their
    header
  * "Set as Main Scene" context option for scenes in the FileSystem dock
  Removed:
  * Unused Panel panelf and panelnc styles.
  * thekla_atlas dependency, as light baking now relies on xatlas
    for UV unwrapping.
  * Rating icons in the Asset Library
  * Some editor languages are no longer available due to missing
    support for RTL and text shaping in Godot.
  * Arabic
  * Bengali
  * Persian
  * Hebrew
  * Hindi
  * Malayalam
  * Sinhalese
  * Tamil
  * Telugu
  * Urdu
  * Android: ARMv6 support.
  * iOS: ARMv7 support.
  Fixed:
  * The Project Manager now remembers the sorting option that was
    previously set
  * Fixed issues with PBR environment mapping
  * Several fixes to the GLES2 renderer
  * Fixed importing BMP images
  * Exporting a project via the command-line now returns a non-zero
    exit code if an error occurred during exporting
  * Fixed autocompletion in the script editor
  And more:
  https://github.com/godotengine/godot/blob/3.2/CHANGELOG.md
* Mon Jan 13 2020 cunix@mail.de
- Sources replaced by upstream without version bump
  to hotfix export templates for HTML5 platform
* Tue Dec  3 2019 Max Mitschke <maxmitschke@fastmail.com>
- Updated bundled library versions within specfile
- Cleaned up specfile
  * Removed defattr directives
  * Use %%license directive for license files
* Sat Nov 30 2019 Martin Liška <mliska@suse.cz>
- Update to 3.1.2
  Fixed:
  * Animation: Fixes for onion skinning support of Skeleton2D
  * AnimationTree: Fixes to AnimationTree and State Machine
  * Audio: Fix seemingly random crashes related to the audio engine misusing
    internal processing
  * CPUParticles(2D): Various fixes
  * GLES2: Many bugfixes
  * GLES3: Many bugfixes
  * Editor: Fix issues when moving and renaming files
  * Export: Fix resetting editor settings when exporting from the
    command line
  * Import: Various improvements to BMP support
  * Internationalization: Various fixes to Control localization,
    and fixes to support of some regional locales
  * iOS: Fix crash on resume/exit on iOS 13
  * macOS: Fix non-HiDPI mode on HiDPI displays on macOS Catalina
  * macOS: Fix locale detection when running from .app bundle
  * Object: Improve instance validation, mitigating thread-related issues
  * Shaders: Fix support for hint_range using integers
  Added:
  * Editor: Allow to removing 2D editor limits
  * Mobile: Add vibration support on Android and iOS
  * TileMap: Add support for negative Y and X offsets
  * API documentation updates.
  * Editor translation updates.
  Third Party Libraries:
  * zstd upgraded to 1.4.4
  * libwebsockets downgraded to 3.0.1 (3.1 caused regressions)
* Sun May 12 2019 Max Mitschke <maxmitschke@fastmail.com>
- Fixing packaging issues for submission to Factory
  * Changed python build requirement for python3
  * Removed no-version-in-last-changelog from rpmlintrc
  * Renamed rpmlintrc to godot-rpmlintrc per openSUSE packaging
    standards
* Mon Apr 29 2019 cunix@bitmessage.ch
- Use system certificates from /var/lib/ca-certificates/ca-bundle.pem
  by default and dynamically. Stop hard coding its content during build.
  These certificates are used by the editor to connect to the Asset Library.
- Added patch file "project_certs_fallback.patch" to use the previously
  defined system certificates as fallback for missing certificates in
  project setting "network/ssl/certificates".
* Sun Apr 28 2019 cunix@bitmessage.ch
- Changes in 3.1.1
  Fixed Security Issue:
  * to deserialize Object data. GDNative ABI was changed.
  Fixed:
  * GLES 3 support for depth textures.
  * GLTF2 importer
  Added:
  * HeightMapShape to the Bullet physics engine implementation
  * FPS snapping in the Animation player
  * audio features for 3.2 were backported
  * menu options for the Sprite editor: "Convert to Mesh2D",
    "Convert to Polygon2D", "Create CollisionPolygon2D Sibling"
    and "Create LightOccluder2D Sibling"
  * AnimatedSprite can now play backwards
  * Emission Mask to CPUParticles2D
  And more:
  https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_changelog.txt
* Sun Apr 28 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
- Require bash for the build due to use of [[ x > y ]].
* Sat Apr 27 2019 Martin Liška <mliska@suse.cz>
- Update to 3.1.1
* Sat Apr 27 2019 Martin Liška <mliska@suse.cz>
- Mention rpmlintrc as a source file.
* Tue Apr 16 2019 Max Mitschke <maxmitschke@fastmail.com>
- Update to 3.1
  * See https://github.com/godotengine/godot/blob/3.1-stable/CHANGELOG.md
* Thu Mar  7 2019 Max Mitschke <maxmitschke@fastmail.com>
- Added export_presets.cfg to be used when one is not present in
  Godot game's source.
* Tue Mar  5 2019 Max Mitschke <maxmitschke@fastmail.com>
- Added godot-headless package
* Tue Feb 26 2019 Martin Liška <mliska@suse.cz>
- Disable lto for anything older than openSUSE 15.0.
* Tue Feb 19 2019 Martin Liška <mliska@suse.cz>
- Rename subpackages to godot-runner and godot-server in order
  to provide same names as in Fedora package
- Do not use -fno-strict-aliasing
- Make output verbose and use LTO (increase RAM requirements).
* Mon Feb 18 2019 cunix@bitmessage.ch
- Added patches to use system certificates
- Added service file for local hash checking
- Added rpmlintrc file to silence warning of missing version in
    changelog and for missing manual-page for server package
* Tue Feb  5 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Use https://en.opensuse.org/SourceUrls
* Wed Jan 30 2019 maxmitschke@fastmail.com
- Updated spec file to better align with openSUSE package
  guidelines
* Sun Jul 29 2018 cunix@bitmessage.ch
- Update to 3.0.6
  Fixed Security Vulnerability:
  * marshalls size checks
  Fixed:
  * vsync initialization
  * can't set AudioStreamPlayer stream to null
  * Basis.Transposed()
  * Several editor crashes
  * GLTF import fixes
  and more
  Upgrade:
  * OpenSSL to 1.0.2o (not used in openSUSE build)
* Wed Jul 11 2018 cunix@bitmessage.ch
- spec changes:
  * build with more shared libraries from the distribution
    instead of bundled versions
  * make build of templates optional
  * unify repetive build arguments
  * include thirdparty/README.md in licenses section
* Tue Jul 10 2018 maxmitschke@fastmail.com
- Update to 3.0.5
  * Android export templates no longer contain the placeholder
    permissions which Google Play started complaining about. Now
    only requested permissions will be written to the manifest when
    exporting.
  * Added 'android_add_asset_dir('...') method to Android module
    gradle build config
  * User defined signals in the exported C# projects were
    misbehaving, this is now fixed.
  * Fix CORS problems due to added headers on JS target
  * Lerp now consistent with Godot API. InverseLerp fixed.
  * Fix debugger focus stealing
  * Fix segfault at quiting editor
* Sun Jul  1 2018 maxmitschke@fastmail.com
- Added openSUSE branding to build info
- Use upstream desktop file, appdata.xml and manpage
- Licenses relocated
- Require update-desktop-files post and postun
- desktop_database only updating explicitly for Leap < 15.0
- Update to 3.0.4
  * Updated documentation for particles, ViewportTexture, Vector2,
    skeleton docs, Rect.abs function
  * Make heightmap shape usable from PhysicsServer
  * Add NoCache wrapper to Command
  * Fixed crasher in asset library on systems with a low threadcount CPU
* Sun Jun 17 2018 maxmitschke@fastmail.com
- Update to 3.0.3
  Added:
  * C# projects can now be exported for Windows, Linux, and MacOS targets.
  * Universal translation of touch to mouse.
  * Dynamic fonts can now have a hinting mode set.
  * print_tree_pretty() was added allowing a graphical view of the scene tree.
  * Restore purchases feature for iOS.
  * AudioStreamPlayer, AudioStreamPlayer2D,
    and AudioStreamPlayer3D now have a pitch scale property.
  * Show origin and Show viewport setting in 2D editor.
  * You can now set Godot windows as 'always on top'.
  * print-fps options to print FPS to stdout.
  Fixed:
  * Mono: Signal parameters no longer crash the engine.
  * Asset library thread usage, this makes the asset library more responsive.
  * Several GLTF import fixes.
  * Several memory leaks.
  * iPhone X support.
  * Several fixes to audio drivers (WASAPI and PulseAudio).
  * Several crashes.
  * Export PCK/ZIP now works again.
* Sat Mar 10 2018 cunix@bitmessage.ch
- Update to 3.0.2
* Tue Feb 27 2018 gwasser@gmail.com
- Update to 3.0.1
* Tue Jan 30 2018 gwasser@gmail.com
- Update to 3.0.0
* Tue Sep  5 2017 dmacvicar@suse.de
- Update to 2.1.4
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Update to 2.1.2
- Add appdata.xml
- Remove fix-arch-detection.patch
- Remove fix-undefined-return.patch
* Mon Jun 27 2016 rpm@fthiessen.de
- Update to 2.0.3
- Added fix-arch-detection.patch to fix ppc build
- Added fix-undefined-return.patch to fix functions with random
  return.
* Mon Jun  1 2015 gber@opensuse.org
- add desktop file
* Sun May 31 2015 gber@opensuse.org
- split examples into subpackage
* Sun May 31 2015 gber@opensuse.org
- initial packaging
